pub trait ContextProvides<V> {
// Required method
fn provide(&self) -> &V;
}Expand description
Signals that the context statically provides a certain type.
Writables may require this bound upon the output’s context in order to implement themselves.
A context that is calculated at runtime should implement ContextProvides<T> for all T, and
panic at runtime if a value is called that is not present.
A context that is calculated statically should implement this trait only for the types it
is statically known to provide.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".