#[non_exhaustive]pub enum Edition {
Rust2015,
Rust2018,
Rust2021,
Rust2024,
}Expand description
All possible Rust editions. This is the only type in this module meant to be used as context, and not as a writable itself.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Rust2015
This Rust edition is declared for usability purposes. However, not all Writable implementations are guaranteed to work with it.
Rust2018
Rust2021
Rust2024